==> camel-k-model-v1-5.3.1-sources.jar: io/fabric8/camelk/v1/IntegrationStatusBuilder.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class IntegrationStatusBuilder extends IntegrationStatusFluentImpl<IntegrationStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<IntegrationStatus,IntegrationStatusBuilder> {

    IntegrationStatusFluent<?> fluent;
    Boolean validationEnabled;

    public IntegrationStatusBuilder() {
        this(true);
    }

    public IntegrationStatusBuilder(Boolean validationEnabled) {
        this(new IntegrationStatus(), validationEnabled);
    }

    public IntegrationStatusBuilder(IntegrationStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public IntegrationStatusBuilder(IntegrationStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new IntegrationStatus(), validationEnabled);
    }

    public IntegrationStatusBuilder(IntegrationStatusFluent<?> fluent,IntegrationStatus instance) {
        this(fluent, instance, true);
    }

    public IntegrationStatusBuilder(IntegrationStatusFluent<?> fluent,IntegrationStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withCapabilities(instance.getCapabilities()); 
        fluent.withConditions(instance.getConditions()); 
        fluent.withConfiguration(instance.getConfiguration()); 
        fluent.withDependencies(instance.getDependencies()); 
        fluent.withDigest(instance.getDigest()); 
        fluent.withFailure(instance.getFailure()); 
        fluent.withGeneratedResources(instance.getGeneratedResources()); 
        fluent.withGeneratedSources(instance.getGeneratedSources()); 
        fluent.withImage(instance.getImage()); 
        fluent.withKit(instance.getKit()); 
        fluent.withLastInitTimestamp(instance.getLastInitTimestamp()); 
        fluent.withPhase(instance.getPhase()); 
        fluent.withPlatform(instance.getPlatform()); 
        fluent.withProfile(instance.getProfile()); 
        fluent.withReplicas(instance.getReplicas()); 
        fluent.withRuntimeProvider(instance.getRuntimeProvider()); 
        fluent.withRuntimeVersion(instance.getRuntimeVersion()); 
        fluent.withSelector(instance.getSelector()); 
        fluent.withVersion(instance.getVersion()); 
        this.validationEnabled = validationEnabled; 
    }

    public IntegrationStatusBuilder(IntegrationStatus instance) {
        this(instance,true);
    }

    public IntegrationStatusBuilder(IntegrationStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withCapabilities(instance.getCapabilities()); 
        this.withConditions(instance.getConditions()); 
        this.withConfiguration(instance.getConfiguration()); 
        this.withDependencies(instance.getDependencies()); 
        this.withDigest(instance.getDigest()); 
        this.withFailure(instance.getFailure()); 
        this.withGeneratedResources(instance.getGeneratedResources()); 
        this.withGeneratedSources(instance.getGeneratedSources()); 
        this.withImage(instance.getImage()); 
        this.withKit(instance.getKit()); 
        this.withLastInitTimestamp(instance.getLastInitTimestamp()); 
        this.withPhase(instance.getPhase()); 
        this.withPlatform(instance.getPlatform()); 
        this.withProfile(instance.getProfile()); 
        this.withReplicas(instance.getReplicas()); 
        this.withRuntimeProvider(instance.getRuntimeProvider()); 
        this.withRuntimeVersion(instance.getRuntimeVersion()); 
        this.withSelector(instance.getSelector()); 
        this.withVersion(instance.getVersion()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.camelk.v1.EditableIntegrationStatus build() {
        EditableIntegrationStatus buildable = new EditableIntegrationStatus(fluent.getCapabilities(),fluent.getConditions(),fluent.getConfiguration(),fluent.getDependencies(),fluent.getDigest(),fluent.getFailure(),fluent.getGeneratedResources(),fluent.getGeneratedSources(),fluent.getImage(),fluent.getKit(),fluent.getLastInitTimestamp(),fluent.getPhase(),fluent.getPlatform(),fluent.getProfile(),fluent.getReplicas(),fluent.getRuntimeProvider(),fluent.getRuntimeVersion(),fluent.getSelector(),fluent.getVersion());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        IntegrationStatusBuilder that = (IntegrationStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> camel-k-model-v1-5.7.0-sources.jar: io/fabric8/camelk/v1/IntegrationStatusBuilder.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class IntegrationStatusBuilder extends io.fabric8.camelk.v1.IntegrationStatusFluentImpl<io.fabric8.camelk.v1.IntegrationStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.camelk.v1.IntegrationStatus,io.fabric8.camelk.v1.IntegrationStatusBuilder> {

    io.fabric8.camelk.v1.IntegrationStatusFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public IntegrationStatusBuilder() {
        this(true);
    }

    public IntegrationStatusBuilder(java.lang.Boolean validationEnabled) {
        this(new IntegrationStatus(), validationEnabled);
    }

    public IntegrationStatusBuilder(io.fabric8.camelk.v1.IntegrationStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public IntegrationStatusBuilder(io.fabric8.camelk.v1.IntegrationStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new IntegrationStatus(), validationEnabled);
    }

    public IntegrationStatusBuilder(io.fabric8.camelk.v1.IntegrationStatusFluent<?> fluent,io.fabric8.camelk.v1.IntegrationStatus instance) {
        this(fluent, instance, true);
    }

    public IntegrationStatusBuilder(io.fabric8.camelk.v1.IntegrationStatusFluent<?> fluent,io.fabric8.camelk.v1.IntegrationStatus instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withCapabilities(instance.getCapabilities()); 
        fluent.withConditions(instance.getConditions()); 
        fluent.withConfiguration(instance.getConfiguration()); 
        fluent.withDependencies(instance.getDependencies()); 
        fluent.withDigest(instance.getDigest()); 
        fluent.withFailure(instance.getFailure()); 
        fluent.withGeneratedResources(instance.getGeneratedResources()); 
        fluent.withGeneratedSources(instance.getGeneratedSources()); 
        fluent.withImage(instance.getImage()); 
        fluent.withKit(instance.getKit()); 
        fluent.withLastInitTimestamp(instance.getLastInitTimestamp()); 
        fluent.withPhase(instance.getPhase()); 
        fluent.withPlatform(instance.getPlatform()); 
        fluent.withProfile(instance.getProfile()); 
        fluent.withReplicas(instance.getReplicas()); 
        fluent.withRuntimeProvider(instance.getRuntimeProvider()); 
        fluent.withRuntimeVersion(instance.getRuntimeVersion()); 
        fluent.withSelector(instance.getSelector()); 
        fluent.withVersion(instance.getVersion()); 
        this.validationEnabled = validationEnabled; 
    }

    public IntegrationStatusBuilder(io.fabric8.camelk.v1.IntegrationStatus instance) {
        this(instance,true);
    }

    public IntegrationStatusBuilder(io.fabric8.camelk.v1.IntegrationStatus instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withCapabilities(instance.getCapabilities()); 
        this.withConditions(instance.getConditions()); 
        this.withConfiguration(instance.getConfiguration()); 
        this.withDependencies(instance.getDependencies()); 
        this.withDigest(instance.getDigest()); 
        this.withFailure(instance.getFailure()); 
        this.withGeneratedResources(instance.getGeneratedResources()); 
        this.withGeneratedSources(instance.getGeneratedSources()); 
        this.withImage(instance.getImage()); 
        this.withKit(instance.getKit()); 
        this.withLastInitTimestamp(instance.getLastInitTimestamp()); 
        this.withPhase(instance.getPhase()); 
        this.withPlatform(instance.getPlatform()); 
        this.withProfile(instance.getProfile()); 
        this.withReplicas(instance.getReplicas()); 
        this.withRuntimeProvider(instance.getRuntimeProvider()); 
        this.withRuntimeVersion(instance.getRuntimeVersion()); 
        this.withSelector(instance.getSelector()); 
        this.withVersion(instance.getVersion()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.camelk.v1.EditableIntegrationStatus build() {
        EditableIntegrationStatus buildable = new EditableIntegrationStatus(fluent.getCapabilities(),fluent.getConditions(),fluent.getConfiguration(),fluent.getDependencies(),fluent.getDigest(),fluent.getFailure(),fluent.getGeneratedResources(),fluent.getGeneratedSources(),fluent.getImage(),fluent.getKit(),fluent.getLastInitTimestamp(),fluent.getPhase(),fluent.getPlatform(),fluent.getProfile(),fluent.getReplicas(),fluent.getRuntimeProvider(),fluent.getRuntimeVersion(),fluent.getSelector(),fluent.getVersion());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        IntegrationStatusBuilder that = (IntegrationStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
